@@ -1,4 +1,3 @@
-from meiga import Result
 from petisco.event.chaos.domain.interface_event_chaos import IEventChaos
 
 
@@ -10,11 +9,11 @@ class NotImplementedEventChaos(IEventChaos):
             "EVENT_CHAOS_PERCENTAGE_SIMULATE_FAILURES": "NOT_IMPLEMENTED",
         }
 
-    def nack_simulation(self, *args, **kwargs):
+    def nack_simulation(self, *args, **kwargs) -> bool:
         return False
 
-    def simulate_failure_on_result(self, result: Result) -> Result:
-        return result
+    def failure_simulation(self) -> bool:
+        return False
 
     def delay(self):
         pass
